@@ -13,13 +13,15 @@ def main():
   log = CustomLogger(__name__).logger
   args = fetch_arguments()
 
+  if args['silent_mode']: log.warning(wrap_orange(f"You are running the tool in -sm/--silent_mode. Thus warning messages will be printed (e.g. SSL warnings, files overwriting warnings) but no confirmation will be asked.\n"))
+
   if not args['cert_verification']:
     urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
   args = check_arguments_conflicts(args, log)
 
   if args['aggregate_only'] == False:
-    check_csv_already_written(args['export_path'])
+    check_csv_already_written(args['export_path'], args['silent_mode'], log, 'query')
 
     log.info(wrap_green(bold("################### EXTRACTING DATA ###################\n")))
 
@@ -59,7 +61,7 @@ def main():
 
     # Joining partial csv files previously created into a single one
     log.info(wrap_blue('Joining partial csv files\n'))
-    final_df = join_partial_csvs(args['export_path'][:-4])
+    final_df = join_partial_csvs(args['export_path'][:-4], args['csv_separator'], args['decimal_separator'])
     
     # Remove duplicates
     final_df = remove_duplicates(args, final_df)
@@ -68,7 +70,7 @@ def main():
 
     # Write the CSV from the dataframe
     log.info(wrap_blue(f'Creating the csv at the following export path --> {args["export_path"]}.\n'))
-    write_csv(args['export_path'], fields_to_export, "Something went wrong when trying to write the final csv after the merge of the partial csv files. The partial csv files won't be deleted.", df=final_df_newcolumns)
+    write_csv(args['export_path'], fields_to_export, args['csv_separator'], args['decimal_separator'], args['decimal_rounding'], "Something went wrong when trying to write the final csv after the merge of the partial csv files. The partial csv files won't be deleted.", df=final_df_newcolumns)
 
     # Delete partial csvs
     if not args['keep_partials']: 
@@ -77,6 +79,7 @@ def main():
 
   # Create aggregation file if needed
   if args['aggregation_fields'] != None:
+    check_csv_already_written(args['aggregated_export_path'], args['silent_mode'], log, 'aggregation')
     if args['aggregate_only']: 
       log.info(wrap_green(bold("################# AGGREGATING RAW FILE ################\n")))
     else:
@@ -86,7 +89,7 @@ def main():
     file_to_aggregate = args['raw_input_file'] if args['aggregate_only'] else args['export_path']
     aggregated_df = aggregate_fields(file_to_aggregate, args, log, args['df_ready'])
     aggregated_df = rename_df_columns(aggregated_df, args['rename_fields'])
-    write_csv(args['aggregated_export_path'], None, f"Something when wrong when trying to write the aggregated dataframe to {args['aggregated_export_path']}. If you exported the raw data from Elasticsearch, the raw csv file will be available at \"{args['export_path']}\". Please use it with the --aggregate_only flag and a proper --aggregation_types and --aggregation_fields configuration to generate your aggregated file.", df=aggregated_df, index=False)
+    write_csv(args['aggregated_export_path'], None,  args['csv_separator'], args['decimal_separator'], args['decimal_rounding'], f"Something when wrong when trying to write the aggregated dataframe to {args['aggregated_export_path']}. If you exported the raw data from Elasticsearch, the raw csv file will be available at \"{args['export_path']}\". Please use it with the --aggregate_only flag and a proper --aggregation_types and --aggregation_fields configuration to generate your aggregated file.", df=aggregated_df, index=False)
     log.info(wrap_blue(f"Aggregated file has been created at path \"{args['aggregated_export_path']}\"\n"))
 
   log.info(wrap_green(bold("################# EXITING SUCCESSFULLY ################\n")))
