@@ -19,7 +19,10 @@ def fetch_arguments():
   ap.add_argument("-c", "--cert_verification", required=False, help="require ssl certificate verification. Default to False. Set to True to enable it", type=real_bool, default=False)
   ap.add_argument("-cbo", "--count_boolean_occurrences", required=False, help="this option might help you in case you want to count the occurrences of a boolean field. All boolean fields that have to be taken into consideration when True, must be passed as a string with commas between fields and no whitespaces (e.g. \"field1,field2\"). Remember to set the aggregation type \"sum\" in the --aggregation_types option for the corresponding aggregation fields", default='')
   ap.add_argument("-cp", "--certificate_path", required=False, help="path to the certificate to verify the instance certificate against", default='')
+  ap.add_argument("-cs", "--csv_separator", required=False, help="separator to use in the CSV resulting files (both raw and aggregated, if any). Default is comma (,). Separators longer than 1 character and different from '\s+' will be interpreted as regular expressions and will also force the use of the Python parsing engine. Note that regex delimiters are prone to ignoring quoted data", default=',')
   ap.add_argument("-dp", "--disable_progressbar", required=False, help="turn off the progressbar visualization useful to keep track of fetching data progresses of various processes. Default to False. Set to True to simply be noticed when processes have done fetching data, without the loading progressbar.", type=real_bool, default=False)
+  ap.add_argument("-dr", "--decimal_rounding", required=False, help="round decimals to this value. Default to 2", type=int, default=2)
+  ap.add_argument("-ds", "--decimal_separator", required=False, help="set the custom decimal separator for your file. Consider one that doesn't mess up with the csv_separator (default to ','). Default is the dot (.)", default='.')
   ap.add_argument("-e", "--export_path", required=False, help="path where to store the csv file. If not set, 'es_export.csv' will be used. Make sure the user who's launching the script is allowed to write to that path. WARNING: At the end of the process, unless --keep_partial is set to True, all the files with filenames \"[--export_path]_process*.csv\" will be remove. Make sure you're setting a --export_path which won't accidentally delete any other file apart from the ones created by this script", type=check_csv_valid_filename, default="es_export.csv")
   ap.add_argument("-ed", "--ending_date", required=False, help="query ending date. Must be set in iso 8601 format, without the timezone that can be specified in the --timezone option (e.g. \"YYYY-MM-ddTHH:mm:ss\")", default='now+1000y')
   ap.add_argument("-em", "--enable_multiprocessing", required=False, help="enable the multiprocess options. Default to False. Set to True to exploit multiprocessing. If set to True a --time_field to sort on must be set or an exception will be raised", type=real_bool, default=False)
@@ -41,6 +44,7 @@ def fetch_arguments():
   ap.add_argument("-rif", "--raw_input_file", required=False, help="required if --aggregate_only is enabled. Path to csv file to import as raw file", default=None)
   ap.add_argument("-s", "--ssl", required=False, help="require ssl connection. Default to False. Set to True to enable it", type=real_bool, default=False)
   ap.add_argument("-sd", "--starting_date", required=False, help="query starting date. Must be set in iso 8601 format, without the timezone that can be specified in the --timezone option (e.g. \"YYYY-MM-ddTHH:mm:ss\")", default='now-1000y')
+  ap.add_argument("-sm", "--silent_mode", required=False, help="set this option to True to run the tool in silent mode, without any user interaction (password request if not specified in -pw or -spw, warning about files overwriting). If you enable this option, consider you won't be asked for anything, so an error will be returned in case a password is missing and files might be overwritten without any confirmation first. Default to False.", type=real_bool, default=False)
   ap.add_argument("-spw", "--secret_password", required=False, help="env var pointing the Elasticsearch password. If both this a --password are not set, a prompt password will be asked anyway (leave it blank if not needed).", default=None)
   ap.add_argument("-t", "--time_field", required=False, help="time field to query on. If not set and --starting_date or --ending_date are set and exception will be raised", default=None)
   ap.add_argument("-tz", "--timezone", required=False, help="timezone to set according to the time zones naming convention (e.g. \"America/New_York\" or \"Europe/Paris\" or \"UTC\"). If not set, the local timezone of the present machine will be used", default=None)
