@@ -2,6 +2,7 @@ import os, logging, getpass, sys
 import dateutil.parser as dateparser
 import pandas as pd
 import numpy as np
+from dateutil import tz
 from .color_wrappers import *
 
 def build_source_query(fields_of_interest):
@@ -50,7 +51,7 @@ def denest(fields, obj):
 
 def final_pw(args, log):
   pw = args['password'] if args['password'] != None else os.environ[args['secret_password']] if args['secret_password'] != None and args['secret_password'] in os.environ else ''
-  if pw == '':
+  if pw == '' and not args['silent_mode']:
     pw = (getpass.getpass("Enter your es instance password. If not needed, press ENTER:  ")).strip()
   if args['user'] == '' and pw != '': log.warning(wrap_orange('You set a password but not a user. You either forgot to set the user or you set a useless password. If something goes wrong with the authentication, this warning might ring a bell :)'))
   return pw
@@ -93,7 +94,7 @@ def rename_df_columns(df, new_columns):
 
 def aggregate_fields(filename, args, log, df_ready=None):
   try:
-    df = pd.read_csv(filename) if df_ready is None else df_ready
+    df = pd.read_csv(filename, sep=args['csv_separator'], decimal=args['decimal_separator']) if df_ready is None else df_ready
     columns_to_keep = []
     aggregation_types = clean_dictionary({"--aggregation_types": args['aggregation_types']}, df.columns, '--aggregation_types', filename, log)
     aggregation_names = clean_dictionary({"--aggregation_types": args['aggregation_types'], "--rename_aggregations": args['rename_aggregations']}, df.columns, '--rename_aggregations', filename, log)
@@ -108,8 +109,10 @@ def aggregate_fields(filename, args, log, df_ready=None):
     agg_time_field = args['aggregation_time_field']
     if agg_time_field is not None and agg_time_field in df.columns:
       agg_timespan = args['aggregation_time_span']
+      timezone = args['timezone'] if args['timezone'] is not None else tz.tzlocal()
       columns_to_keep = list(set(columns_to_keep + [agg_time_field]))
       df[agg_time_field] = pd.to_datetime(df[agg_time_field])
+      df[agg_time_field] = df[agg_time_field].dt.tz_convert(timezone)
       df = df.set_index(agg_time_field)
       aggregation_fields.insert(0, pd.Grouper(level=agg_time_field, freq=f"{agg_timespan}d"))
       
